Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAndre Weinand2002-05-31 20:49:35 +0000
committerAndre Weinand2002-05-31 20:49:35 +0000
commitd7925c85f30eb418b024bf62fd8e90be6e836090 (patch)
tree7a6c70a85ebb9c478e1dc2e336b5fb5e12280be5
parentbe935f2b8d81798b4e8b0037e7b99db0f05f3e11 (diff)
downloadeclipse.platform.team-d7925c85f30eb418b024bf62fd8e90be6e836090.tar.gz
eclipse.platform.team-d7925c85f30eb418b024bf62fd8e90be6e836090.tar.xz
eclipse.platform.team-d7925c85f30eb418b024bf62fd8e90be6e836090.zip
#17463: Replace with previous element from local history should ignore unparseable versions
-rw-r--r--bundles/org.eclipse.compare/buildnotes_compare.html1
-rw-r--r--bundles/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java7
-rw-r--r--bundles/org.eclipse.compare/plugins/org.eclipse.compare/buildnotes_compare.html1
-rw-r--r--bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java7
4 files changed, 12 insertions, 4 deletions
diff --git a/bundles/org.eclipse.compare/buildnotes_compare.html b/bundles/org.eclipse.compare/buildnotes_compare.html
index eb7a4cb22..36080d281 100644
--- a/bundles/org.eclipse.compare/buildnotes_compare.html
+++ b/bundles/org.eclipse.compare/buildnotes_compare.html
@@ -36,6 +36,7 @@ Problem reports fixed</h2>
<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=18200">#18200</a>: Both sets of arrows say "Select Next Change"<br>
<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=18206">#18206</a>: Casing, wording issue on "Last Resource reached" prompt<br>
<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=16285">#16285</a>: Add from Local History needs a description label<br>
+<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=17431">#17431</a>: Accessibility issues<br>
<h2>
Problem reports closed</h2>
diff --git a/bundles/org.eclipse.compare/plugins/org.eclipse.compare/buildnotes_compare.html b/bundles/org.eclipse.compare/plugins/org.eclipse.compare/buildnotes_compare.html
index eb7a4cb22..36080d281 100644
--- a/bundles/org.eclipse.compare/plugins/org.eclipse.compare/buildnotes_compare.html
+++ b/bundles/org.eclipse.compare/plugins/org.eclipse.compare/buildnotes_compare.html
@@ -36,6 +36,7 @@ Problem reports fixed</h2>
<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=18200">#18200</a>: Both sets of arrows say "Select Next Change"<br>
<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=18206">#18206</a>: Casing, wording issue on "Last Resource reached" prompt<br>
<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=16285">#16285</a>: Add from Local History needs a description label<br>
+<a href="http://dev.eclipse.org/bugs/show_bug.cgi?id=17431">#17431</a>: Accessibility issues<br>
<h2>
Problem reports closed</h2>
diff --git a/bundles/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java b/bundles/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java
index 796c3b472..ad21c2bab 100644
--- a/bundles/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java
+++ b/bundles/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java
@@ -232,12 +232,12 @@ public class EditionSelectionDialog extends ResizableDialog {
}
/**
- * Select the previous edition.
+ * Select the previous edition (presenting a UI).
*
* @param target the input object against which the editions are compared; must not be <code>null</code>
* @param editions the list of editions (element type: <code>ITypedElement</code>s)
* @param path If <code>null</code> dialog shows full input; if non <code>null</code> it extracts a subsection
* @return returns the selected edition or <code>null</code> if dialog was cancelled.
* The returned <code>ITypedElement</code> is one of the original editions
* if <code>path</code> was <code>null</code>; otherwise
* it is an <code>ITypedElement</code> returned from <code>IStructureCreator.locate(path, item)</code>
@@ -289,6 +289,9 @@ public class EditionSelectionDialog extends ResizableDialog {
pair= new Pair(null, edition);
}
+ if (pair != null && pair.fHasError)
+ return null;
+
if (pair != null && !fTargetPair.equals(pair)) {
return pair.fItem;
}
@@ -232,12 +232,12 @@ public class EditionSelectionDialog extends ResizableDialog {
* @param editions the list of editions (element type: <code>ITypedElement</code>s)
* @param path If <code>null</code> dialog shows full input; if non <code>null</code> it extracts a subsection
- * @return returns the selected edition or <code>null</code> if dialog was cancelled.
+ * @return returns the selected edition or <code>null</code> if error occurred.
* The returned <code>ITypedElement</code> is one of the original editions
* if <code>path</code> was <code>null</code>; otherwise
diff --git a/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java b/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java
index 796c3b472..ad21c2bab 100644
--- a/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java
+++ b/bundles/org.eclipse.compare/plugins/org.eclipse.compare/compare/org/eclipse/compare/EditionSelectionDialog.java
@@ -232,12 +232,12 @@ public class EditionSelectionDialog extends ResizableDialog {
}
/**
- * Select the previous edition.
+ * Select the previous edition (presenting a UI).
*
* @param target the input object against which the editions are compared; must not be <code>null</code>
* @param editions the list of editions (element type: <code>ITypedElement</code>s)
* @param path If <code>null</code> dialog shows full input; if non <code>null</code> it extracts a subsection
* @return returns the selected edition or <code>null</code> if dialog was cancelled.
* The returned <code>ITypedElement</code> is one of the original editions
* if <code>path</code> was <code>null</code>; otherwise
* it is an <code>ITypedElement</code> returned from <code>IStructureCreator.locate(path, item)</code>
@@ -289,6 +289,9 @@ public class EditionSelectionDialog extends ResizableDialog {
pair= new Pair(null, edition);
}
+ if (pair != null && pair.fHasError)
+ return null;
+
if (pair != null && !fTargetPair.equals(pair)) {
return pair.fItem;
}
@@ -232,12 +232,12 @@ public class EditionSelectionDialog extends ResizableDialog {
* @param editions the list of editions (element type: <code>ITypedElement</code>s)
* @param path If <code>null</code> dialog shows full input; if non <code>null</code> it extracts a subsection
- * @return returns the selected edition or <code>null</code> if dialog was cancelled.
+ * @return returns the selected edition or <code>null</code> if error occurred.
* The returned <code>ITypedElement</code> is one of the original editions
* if <code>path</code> was <code>null</code>; otherwise

Back to the top